GOOF----LE-8-2.0=J      ] 4    hw      ] g  guile	 	g  process-use-modules	 	 	g  gnucash	g  	app-utils	 		 	
g  Ind	f  Individual, Joint, etc.	f  Umsatzsteuer-Kennzahlen	
 	g  Other	f  None	f  &Keine Steuerberichtsoptionen vorhanden	 	g  txf-tax-entity-types	g  assv	g  gnc:tax-type-txf-get-code-info	g  gnc:txf-get-tax-entity-type	g  'gnc:txf-get-tax-entity-type-description	g  map	g  car	g  !gnc:txf-get-tax-entity-type-codes	g  gnc:txf-get-code-info	g  gnc:txf-get-payer-name-source	g  gnc:txf-get-form	g  gnc:txf-get-description	g  gnc:txf-get-format	g  gnc:txf-get-multiple	 g  gnc:txf-get-category-key	!g  string->symbol	"g  
vector-length	#g  gnc:txf-get-line-data	$g  gnc:txf-get-last-year	%g  txf-help-strings	&f  Keine Hilfe verfgbar, da nur Gruppenberschrift.
Diese Kategorie ohne Nummer ==>> N I C H T   V E R W E N D E N !
USt-Kategorien 2011 fr GnuCash Vers. 2.4.0 entwickelt und erstellt von: FJSW
Fehlermeldungen + Dankschreiben an: stoll@bomhardt.de	'g  gnc:txf-get-help	(f   	)g  gnc:txf-get-codes	*g  H000	+g  current	,f  help	-f  *Name des aktuellen Kontos wird exportiert.	.+,-
( 	/g  H002	0g  parent	1f  /Name des bergeordneten Kontos wird exportiert.	20,1
( 	3g  H003	4g  not-impl	5f  )Noch nicht implementiert, NICHT benutzen!	64,5
( 	7g  txf-help-categories	8g  N000	9g  none	:f  7Informativ im Steuerbericht anzeigen -- Kein Export -- 	;9(:
( 	<g  UST	=f  CDiese und nachfolgende Kategorien ohne Nummer --> NICHT VERWENDEN !	>9(=
( 	?g  U00	@f  PLieferungen und sonstige Leistungen (einschlielich unentgeltlicher Wertabgaben)	A9(@
( 	Bg  U10	Cf  &Steuerfreie Umstze mit Vorsteuerabzug	D9(C
( 	Eg  U11	Ff  =Innergemeinschaftliche Lieferungen ( 4 Nr. 1 Buchst. b UStG)	G9(F
( 	Hg  K41	If  41	Jf  an Abnehmer MIT USt-IdNr.	K9IJ	I 	Lg  K44	Mf  44	Nf  *neuer Fahrzeuge an Abnehmer OHNE USt-IdNr.	O9MN	M 	Pg  K49	Qf  49	Rf  8neuer Fahrzeuge auerhalb eines Unternehmens ( 2a UStG)	S9QR	Q 	Tg  K43	Uf  43	Vf  .Weitere steuerfreie Umstze mit Vorsteuerabzug	W9UV	U 	Xg  U12	Yf  'Steuerfreie Umstze ohne Vorsteuerabzug	Z9(Y
( 	[g  K48	\f  48	]f  "Umstze nach  4 Nr. 8 bis 28 UStG	^9\]	\ 	_g  U20	`f  `Steuerpflichtige Umstze (Lieferungen u. sonst. Leistungen einschl. unentgeltlicher Wertabgaben)	a9(`
( 	bg  K51	cf  51	df  )zum Steuersatz von 16 %  (bis incl. 2006)	e9cd	c 	fg  K81	gf  81	hf  zum Steuersatz von 19 %	i9gh	g 	jg  K86	kf  86	lf  zum Steuersatz von  7 %	m9kl	k 	ng  K35	of  35	pf   zu anderen Steuerstzen (Erlse)	q9op	o 	rg  K36	sf  36	tf  zu anderen Steuerstzen (MWSt)	u9sts 	vg  U21	wf  CLieferungen land- und forstwirtschaftlicher Betriebe nach  24 UStG	x9(w
( 	yg  K77	zf  77	{9zJ	z 	|g  K76	}f  76	~f  FUmstze, fr die eine Steuer nach  24 UStG zu entrichten ist (Erlse)	9}~	}  g  K80 f  80 f  DUmstze, fr die eine Steuer nach  24 UStG zu entrichten ist (MWSt) 9  g  U30 f  Innergemeinschaftliche Erwerbe 9(
(  g  U32 f  /Steuerpflichtige innergemeinschaftliche Erwerbe 9(
(  g  K98 f  98 f  'zu anderen Steuerstzen (Gebuchte MWSt) 9  g  K96 f  96 f  Wneuer Fahrzeuge von Lieferern OHNE USt-IdNr. zum allgemeinen Steuersatz (Gebuchte MWSt) 9  g  U40 f  Ergnzende Angaben zu Umstzen 9(
(  g  K42 f  42 f  _Lieferungen des ersten Abnehmers bei innergemeinschaftl. Dreiecksgeschften ( 25b Abs. 2 UStG) 9	  g  K60 f  60 f  cSteuerpflichtige Umstze, fr die der Leistungsempfnger die Steuer nach  13b Abs. 5 UStG schuldet 9	  g  K21 f  21 f  VNicht steuerbare sonstige Leistungen gem.  18b Satz 1 Nr. 2 UStG (Leistungen EU-Land) 9	  g  K45 f  45 f  >brige nicht steuerbare Umstze (Leistungsort nicht im Inland) 9	  g  U50 f  3Leistungsempfnger als Steuerschuldner ( 13b UStG) 9(
(  g  K47 f  47 f  `Im Inland steuerpflichtige sonstige Leistungen aus EU-Lndern (13b Abs. 1 UStG) (Gebuchte MWSt) 9  g  K53 f  53 f  jAndere Leistungen eines im Ausland ansssigen Unternehmers ( 13b Abs. 2 Nr. 1 und 5 UStG) (Gebuchte MWSt) 9  g  K74 f  74 f  hLieferungen sicherheitsbereigneter Gegenstnde und Umstze, die unter das GrEStG fallen (Gebuchte MWSt) 9  g  K85 f  85 f  pAndere Umstze eines im Inland ansssigen Unternehmers ( 13b Abs. 2 Nr. 4 und Nr. 6 bis 9 UStG) (Gebuchte MWSt) 9  g  U70 f  Andere Steuerbetrge 9(
(  g  K65 f  65 f  _Steuer infolge Wechsels der Besteuerungsform sowie Nachsteuer auf versteuerte Anzahlungen u. . 9  g  K69 f  69 f  QIn Rechnungen unrichtig oder unberechtigt ausgewiesene Steuerbetrge ( 14c UStG) 9  g  txf-income-categories g  U31 f  *Steuerfreie innergemeinschaftliche Erwerbe 9(
(  g  K91 f  91 f  Erwerbe nach  4b UStG 9	  g  K89 f  89 9h	  g  K93 f  93 9l	  g  K95 f  95 f  !zu anderen Steuerstzen (Aufwand) 9	  g  K94 f  94 f  Qneuer Fahrzeuge von Lieferern OHNE USt-IdNr. zum allgemeinen Steuersatz (Aufwand) 9	  g  K46 f  46 f  ZIm Inland steuerpflichtige sonstige Leistungen aus EU-Lndern (13b Abs. 1 UStG) (Aufwand) 9	  g  K52 f  52 f  dAndere Leistungen eines im Ausland ansssigen Unternehmers ( 13b Abs. 2 Nr. 1 und 5 UStG) (Aufwand) 9	  g  K73 f  73 f  aLieferungen sicherheitsbereigneter Gegenstnde und Umstze die unter das GrEStG fallen (Aufwand) 9	  g  K84 f  84 f  jAndere Umstze eines im Inland ansssigen Unternehmers ( 13b Abs. 2 Nr. 4 und Nr. 6 bis 9 UStG) (Aufwand) 9	  g  U60 f  Abziehbare Vorsteuerbetrge 9(
(  g  K66 f  66 f  XVorsteuerbetrge aus Rechnungen von anderen Unternehmern ( 15 Abs. 1 Satz 1 Nr. 1 UStG) 9  g  K61 f  61 f  WVorsteuerbetrge aus dem innergemeinschaftlichen Erwerb von Gegenstnden (Gebuchte VSt) 9  g  K62 f  62 f  ?Entrichtete Einfuhrumsatzsteuer ( 15 Abs. 1 Satz 1 Nr. 2 UStG) 9  g  K67 f  67 f  fVorsteuerbetrge aus Leistungen im Sinne des  13b UStG ( 15 Abs. 1 Satz 1 Nr. 4 UStG) (Gebuchte VSt) 9  g  K63 f  63 f  ^Vorsteuerbetrge, die nach allgemeinen Durchschnittsstzen berechnet sind ( 23 und 23a UStG) 9  g  K64f  64f  -Berichtigung des Vorsteuerabzugs ( 15a UStG)9 g  K59f  59f  _Vorsteuerabzug fr innergemeinschaftl. Lieferungen neuer Fahrzeuge auerhalb eines Unternehmens9 g  K39	f  39
f  ZAnrechnung (Abzug) der festgesetzten Sondervorauszahlung (1/11) fr Dauerfristverlngerung9	
	 g  txf-expense-categories
f  zu anderen Steuerstzen9
	 g  txf-asset-categoriesg  txf-liab-eq-categoriesg  gnc:make-string-optiong  gnc:*tax-label*g  gnc:*tax-nr-label*f  af  *The electronic tax number of your businessg  gnc:register-optiong  book-options-generatorg  !gnc-register-kvp-option-generatorg  QOF-ID-BOOK-SCMC 5    h  s  ] 4	 >  "  G  

 R   h0   U  ]4 5$  4 5$  CCC     M      g  tax-entity-types
		+ g  	type-code		+ g  index			+ g  tax-entity-type			)  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	6
		7			7			8			8		 	9		#	:		&	:	 			+	  g  nameg  gnc:tax-type-txf-get-code-info CR        h      ] 
6            g  	type-code
		  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	=
		>	 		  g  nameg  gnc:txf-get-tax-entity-type CR h      ] 6            g  	type-code
		  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	@
		A	 		  g  nameg  'gnc:txf-get-tax-entity-type-description CR   h      ] 6             g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	C
	
	D	 		

  g  nameg  !gnc:txf-get-tax-entity-type-codes CR     h     ] 
6          g  
categories
		
 g  code		
 g  tax-entity-type			
  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	F
	
	G	 		
	  g  nameg  gnc:txf-get-payer-name-source CR h      ] 6          g  
categories
		
 g  code		
 g  tax-entity-type			
  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	H
	
	I	 		
	  g  nameg  gnc:txf-get-form CR      h      ] 	6         g  
categories
		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	J
		K	 			  g  nameg  gnc:txf-get-description CR       h      ] 	6         g  
categories
		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	L
		M	 			  g  nameg  gnc:txf-get-format CR    h      ] 	6         g  
categories
		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	N
		O	 			  g  nameg  gnc:txf-get-multiple CR  h     ] 	6         g  
categories
		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	P
		Q	 			  g  nameg  gnc:txf-get-category-key C R!"        hp     ]445 5$  V445 545$  
45"  $  45	"  $  C 	6C          g  
categories
		l g  code		l g  tax-entity-type			l g  tax-entity-codes		#	j g  category		@	j  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	R
		S			S			S			S			T	$		T	*	"	T	$	#	T		#	T		&	V		2	V		3	W		@	T		H	Y		I	Y	&	N	Y	5	P	Y	&	S	Y	#	X	Y		\	Y		j	[	 		l	  g  nameg  gnc:txf-get-line-data C#R!"       hp     ]445 5$  V445 545$  
45"  $  45	"  $  C 	6C          g  
categories
		l g  code		l g  tax-entity-type			l g  tax-entity-codes		#	j g  category		@	j  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	]
		^			^			^			^			_	$		_	*	"	_	$	#	_		#	_		&	a		2	a		3	b		@	_		H	d		I	d	&	N	d	5	P	d	&	S	d	#	X	d		\	d		j	f	 		l	  g  nameg  gnc:txf-get-last-year C$R%& h      ]
45$  CC            g  
categories
		 g  code		 g  pair			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	i
		j			j			k			l			m	 			  g  nameg  gnc:txf-get-help C'R!(
       hP     ]445 5$  74$  "  45 5$  "  6C         g  
categories
		M g  tax-entity-type		M g  tax-entity-code-list-pair		1	K g  tax-entity-codes		A	K  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
	r
		s			s			s			s			t	(		t	H		t	2	 	t	.	"	u	/	'	v	/	1	t	(	1	t		9	x		<	y	#	A	z	#	A	t		K	{	 		M	  g  nameg  gnc:txf-get-codes C)R(
!    hP     ]4$  "  45 5$  "  45$  CC           g  
categories
		K g  code		K g  index			K g  tax-entity-type			K g  tax-entity-code-list-pair			K g  tax-entity-codes		/	K g  category		:	K  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 
	 	$		 	D	
 	.	 	*	 	.	 	.	 	$	 		' 		* 		/ 		/ 		2 		: 		B 		E 		H 	 		K	  g  nameg  gnc:txf-get-code-info CR*./236 7R
8;<>?ABDEGHKLOPSTWXZ[^_abefijmnqruvxy{| '8;  R
8;<>ƌʌ͌ЌԌ،܌  8;  R
8;<>ƌʌ͌Ќ،܌  8;  R
8;<>_aruvx 8;  R( h      ]	45 6           g  options
		 g  
new-option		  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
U
	Z		\		
\		\	:	Z		Y		W	 			  g  nameg  book-options-generator CRiii6       k      g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm		/
		3				3			3			4			 	4		!	4		$	2		'	1
	6
	=
	@
	C
	F
	H
	J
	>	L

`	N
	P

	R
E	]
	i
	r
 
 		 	 	 		 	 	 		 	  	# 	& 
( 	* 		, 	- 	/ 		1 	2 	4 		6 	7 	9 		; 	< 	> 		@ 	A 	C 		E 	F 	H 		J 	K 	M 		O 	P 	R 		T 	U 	W 		Y 	Z 	\ 		^ 	_ 	a 		c 	d 	f 		h 	i 	k 		m 	n 	p 		r 	s 	u 		w 	x 	z 		| 	} 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 	 	 	
 	 	 	  
 	 		 	  	 		 	 	 			 	
 	 		 	 	 		 	 	 		 	 	 		 	 	  		" 	# 	% 		' 	( 	* 		, 	- 	/ 		1 	2 	4 		6 	7 	9 		; 	< 	> 		@ 	A 	C 		E 	F 	H 		J 	K 	M 		O 	P 	R 		T 	U 	W 		Y 	Z 	\ 		^ 	_ 	a 		c 	d 	g 		j 	k 	n 		q 	r 	t 		v 	w 	z 		} 	~ 	 	 					 	  
																																																																										 		 	 	!		!	!	"		"	"	#		#	#	$		$	$	
	(	*		*	*	)	 
"1	$3		&3	'3	)4		+4	,4	.6		06	16	37		57	67	88		:8	;8	=9		?9	@9	B;		D;	E;	G<		I<	J<	L=		N=	O=	Q>		S>	T>	V@		X@	Y@	[A		]A	^A	`B		bB	cB	eC		gC	hC	jD		lD	mD	oF		qF	rF	tG		vG	wG	yH		{H	|H	I		I	I	2	M	O		O	O	N	0/
U
	_
		
   C6 